Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1601)

Unified Diff: sandbox/linux/services/thread_helpers.cc

Issue 2022983003: Roll base to 5e00da80f6adb7082d1c0e88d3274cf87cc43bc5 and tonic to f7acabb8fa6c91124486a41194eac3cd… (Closed) Base URL: https://github.com/domokit/mojo.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sandbox/linux/services/thread_helpers.cc
diff --git a/sandbox/linux/services/thread_helpers.cc b/sandbox/linux/services/thread_helpers.cc
index c1ba04a248c37c75346690dfdfaa5297dbd5c713..89648bc0aec06da77e8daa85d11358ccf8f0914f 100644
--- a/sandbox/linux/services/thread_helpers.cc
+++ b/sandbox/linux/services/thread_helpers.cc
@@ -121,12 +121,12 @@ bool ChangeThreadStateAndWatchProcFS(
const char* message;
if (action == ThreadAction::Start) {
// Should start the thread before calling thread_id().
if (!thread->Start())
return false;
}
- const base::PlatformThreadId thread_id = thread->thread_id();
+ const base::PlatformThreadId thread_id = thread->GetThreadId();
const std::string thread_id_dir_str =
"self/task/" + base::IntToString(thread_id) + "/";
« no previous file with comments | « mojo/android/system/src/org/chromium/mojo/system/impl/CoreImpl.java ('k') | services/http_server/http_request_parser.cc » ('j') | no next file with comments »
@@ -121,12 +121,12 @@ bool ChangeThreadStateAndWatchProcFS(
const char* message;
if (action == ThreadAction::Start) {
- // Should start the thread before calling thread_id().
+ // Should start the thread before calling GetThreadId().
if (!thread->Start())
return false;

Powered by Google App Engine
This is Rietveld 408576698